% Auto-generated chapter 7 for tirmidhi
% Hadiths in this chapter: 65

\hadithdefcmd{tirmidhi}{617}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ التَّمِيمِيُّ الْكُوفِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ ‏.‏ قَالَ فَرَآنِي مُقْبِلاً فَقَالَ ‏"‏ هُمُ الأَخْسَرُونَ وَرَبِّ الْكَعْبَةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ مَا لِي لَعَلَّهُ أُنْزِلَ فِيَّ شَيْءٌ ‏.‏ قَالَ قُلْتُ مَنْ هُمْ فِدَاكَ أَبِي وَأُمِّي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُمُ الأَكْثَرُونَ إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ فَحَثَا بَيْنَ يَدَيْهِ وَعَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَمُوتُ رَجُلٌ فَيَدَعُ إِبِلاً أَوْ بَقَرًا لَمْ يُؤَدِّ زَكَاتَهَا إِلاَّ جَاءَتْهُ يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا كَانَتْ وَأَسْمَنَهُ تَطَؤُهُ بِأَخْفَافِهَا وَتَنْطَحُهُ بِقُرُونِهَا كُلَّمَا نَفِدَتْ أُخْرَاهَا عَادَتْ عَلَيْهِ أُولاَهَا حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ مِثْلُهُ ‏.‏ وَعَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ رضى الله عنه قَالَ لُعِنَ مَانِعُ الصَّدَقَةِ ‏.‏ وَعَنْ قَبِيصَةَ بْنِ هُلْبٍ عَنْ أَبِيهِ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاسْمُ أَبِي ذَرٍّ جُنْدُبُ بْنُ السَّكَنِ وَيُقَالُ ابْنُ جُنَادَةَ ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ عَنْ عُبَيْدِ اللَّهِ بْنِ مُوسَى عَنْ سُفْيَانَ الثَّوْرِيِّ عَنْ حَكِيمِ بْنِ الدَّيْلَمِ عَنِ الضَّحَّاكِ بْنِ مُزَاحِمٍ قَالَ الأَكْثَرُونَ أَصْحَابُ عَشَرَةِ آلاَفٍ ‏.‏ قَالَ وَعَبْدُ اللَّهِ بْنُ مُنِيرٍ مَرْوَزِيٌّ رَجُلٌ صَالِحٌ ‏.‏\hadithno{617}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Dharr narrated:"I came to the Messenger of Allah while he was sitting in the shade of the Ka'bah." He said: "He saw me approaching and he said: 'They are lost on the Day of Judgment! By the Lord of the Ka'bah!'" He said: "I said t myself: Woe is me! Perhaps something has been revealed about me!'" He said: "So I said: 'Who are they, and may my father and mother be ransomed for you.' So the Messenger of Allah said: 'They are those who have much, except for who says like this, and this, and this and motioned with his hand to his front, and t his right, and to his left.' Then he said: 'By the One in Whose Hand is my soul! No man will die, leaving a camel or a cow that he did not pay Zakat on, except that it will come on the Day of Judgment larger and fatter than it was, they will tread him under their hooves and butt him with their horns, all of them; such that when the last of them has had a turn, the first returns to him, until he is judged before the people}}
\hadithdefcmd{tirmidhi}{618}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنِ ابْنِ حُجَيْرَةَ، هُوَ عَبْدُ الرَّحْمَنِ بْنُ حُجَيْرَةَ الْمِصْرِيُّ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَدَّيْتَ زَكَاةَ مَالِكَ فَقَدْ قَضَيْتَ مَا عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ أَنَّهُ ذَكَرَ الزَّكَاةَ ‏.‏ فَقَالَ رَجَلٌ يَا رَسُولَ اللَّهِ هَلْ عَلَىَّ غَيْرُهَا فَقَالَ ‏"‏ لاَ إِلاَّ أَنْ تَتَطَوَّعَ ‏"‏ ‏.‏\hadithno{618}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated :that the Prophet said: "When you pay the Zakat you have fulfilled what is required of you}}
\hadithdefcmd{tirmidhi}{619}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ الْحَمِيدِ الْكُوفِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كُنَّا نَتَمَنَّى أَنْ يَأْتِيَ، الأَعْرَابِيُّ الْعَاقِلُ فَيَسْأَلَ النَّبِيَّ صلى الله عليه وسلم وَنَحْنُ عِنْدَهُ فَبَيْنَا نَحْنُ عَلَى ذَلِكَ إِذْ أَتَاهُ أَعْرَابِيٌّ فَجَثَا بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ إِنَّ رَسُولَكَ أَتَانَا فَزَعَمَ لَنَا أَنَّكَ تَزْعُمُ أَنَّ اللَّهَ أَرْسَلَكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي رَفَعَ السَّمَاءَ وَبَسَطَ الأَرْضَ وَنَصَبَ الْجِبَالَ آللَّهُ أَرْسَلَكَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ رَسُولَكَ زَعَمَ لَنَا أَنَّكَ تَزْعُمُ أَنَّ عَلَيْنَا خَمْسَ صَلَوَاتٍ فِي الْيَوْمِ وَاللَّيْلَةِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ رَسُولَكَ زَعَمَ لَنَا أَنَّكَ تَزْعُمُ أَنَّ عَلَيْنَا صَوْمَ شَهْرٍ فِي السَّنَةِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ رَسُولَكَ زَعَمَ لَنَا أَنَّكَ تَزْعُمُ أَنَّ عَلَيْنَا فِي أَمْوَالِنَا الزَّكَاةَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ رَسُولَكَ زَعَمَ لَنَا أَنَّكَ تَزْعُمُ أَنَّ عَلَيْنَا الْحَجَّ إِلَى الْبَيْتِ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَبِالَّذِي أَرْسَلَكَ آللَّهُ أَمَرَكَ بِهَذَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَقَالَ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَدَعُ مِنْهُنَّ شَيْئًا وَلاَ أُجَاوِزُهُنَّ ‏.‏ ثُمَّ وَثَبَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ صَدَقَ الأَعْرَابِيُّ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ قَالَ بَعْضُ أَهْلِ الْعِلْمِ فِقْهُ هَذَا الْحَدِيثِ أَنَّ الْقِرَاءَةَ عَلَى الْعَالِمِ وَالْعَرْضَ عَلَيْهِ جَائِزٌ مِثْلُ السَّمَاعِ ‏.‏ وَاحْتَجَّ بِأَنَّ الأَعْرَابِيَّ عَرَضَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَقَرَّ بِهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{619}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas narrated:"We used to hope that an intelligent Bedouin would show up to question the Prophet while we were with him. So one while we were with him, a Bedouin came, kneeling in front of the Prophet, and he said: 'O Muhammad, your messenger came to us and told us that you say that Allah sent you.' So the Prophet say: 'Yes.' He said, 'So, (swear) by the One who raised the heaves, and spread out the earth, and erected the mountains; has Allah sent you?' The Prophet said, 'Yes.' He said: 'Your messenger told us that you say that there are five prayers required from us in a day and a night.' The Prophet said, 'Yes.' He said, 'By the One Who sent you, has Allah ordered that you you?' He said, 'Yes.' He said, 'Your messenger told us that you say that we are required to fast for a month out of the year.' He said, 'He told the truth.' He said, 'By the One Who sent you, has Allah ordered that you?' The Prophet said, 'Yes.' He said, 'Your messenger told us that Zakat is required from our wealth.' The Prophet said, 'He told the truth.' He said, 'By the One Who sent you, has Allah ordered you that?' The Prophet said, 'Yes.' He said, 'Your messenger told us that you say that we are required to perform Hajj to Allah's House if able to undertake the journey.' The Prophet said, 'Yes.' He said, 'By the One Who sent you, has Allah Commanded you that?' (The Prophet said:) 'Yes.' So he said: 'By the One Who sent you with the Truth, I will not leave any of them, nor surpass them.' Then he got up quickly (leaving). The Prophet said: 'If the Bedouin told the truth, then he will enter Paradise}}
\hadithdefcmd{tirmidhi}{620}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ عَفَوْتُ عَنْ صَدَقَةِ الْخَيْلِ وَالرَّقِيقِ فَهَاتُوا صَدَقَةَ الرِّقَةِ مِنْ كُلِّ أَرْبَعِينَ دِرْهَمًا دِرْهَمًا وَلَيْسَ فِي تِسْعِينَ وَمِائَةٍ شَيْءٌ فَإِذَا بَلَغَتْ مِائَتَيْنِ فَفِيهَا خَمْسَةُ الدَّرَاهِمِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَعَمْرِو بْنِ حَزْمٍ ‏.‏ قَالَ أَبُو عِيسَى رَوَى هَذَا الْحَدِيثَ الأَعْمَشُ وَأَبُو عَوَانَةَ وَغَيْرُهُمَا عَنْ أَبِي إِسْحَاقَ عَنْ عَاصِمِ بْنِ ضَمْرَةَ عَنْ عَلِيٍّ وَرَوَى سُفْيَانُ الثَّوْرِيُّ وَابْنُ عُيَيْنَةَ وَغَيْرُ وَاحِدٍ عَنْ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ كِلاَهُمَا عِنْدِي صَحِيحٌ عَنْ أَبِي إِسْحَاقَ يُحْتَمَلُ أَنْ يَكُونَ رُوِيَ عَنْهُمَا جَمِيعًا ‏.‏\hadithno{620}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that :the Messenger of Allah said: "I have exempted charity on horses and slaves. So bring charity for silver, one Dirham for every forty Dirham. There is nothing for me (to collect) on one hundred and ninety Dirham, so when it reaches two hundred, then five Dirham of it (are due)}}
\hadithdefcmd{tirmidhi}{621}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، وَإِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ الْهَرَوِيُّ، وَمُحَمَّدُ بْنُ كَامِلٍ الْمَرْوَزِيُّ الْمَعْنَى، وَاحِدٌ، قَالُوا حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ كِتَابَ الصَّدَقَةِ فَلَمْ يُخْرِجْهُ إِلَى عُمَّالِهِ حَتَّى قُبِضَ فَقَرَنَهُ بِسَيْفِهِ فَلَمَّا قُبِضَ عَمِلَ بِهِ أَبُو بَكْرٍ حَتَّى قُبِضَ وَعُمَرُ حَتَّى قُبِضَ وَكَانَ فِيهِ ‏ "‏ فِي خَمْسٍ مِنَ الإِبِلِ شَاةٌ وَفِي عَشْرٍ شَاتَانِ وَفِي خَمْسَ عَشْرَةَ ثَلاَثُ شِيَاهٍ وَفِي عِشْرِينَ أَرْبَعُ شِيَاهٍ وَفِي خَمْسٍ وَعِشْرِينَ بِنْتُ مَخَاضٍ إِلَى خَمْسٍ وَثَلاَثِينَ فَإِذَا زَادَتْ فَفِيهَا ابْنَةُ لَبُونٍ إِلَى خَمْسٍ وَأَرْبَعِينَ فَإِذَا زَادَتْ فَفِيهَا حِقَّةٌ إِلَى سِتِّينَ فَإِذَا زَادَتْ فَفِيهَا جَذَعَةٌ إِلَى خَمْسٍ وَسَبْعِينَ فَإِذَا زَادَتْ فَفِيهَا ابْنَتَا لَبُونٍ إِلَى تِسْعِينَ فَإِذَا زَادَتْ فَفِيهَا حِقَّتَانِ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ عَلَى عِشْرِينَ وَمِائَةٍ فَفِي كُلِّ خَمْسِينَ حِقَّةٌ وَفِي كُلِّ أَرْبَعِينَ ابْنَةُ لَبُونٍ ‏.‏ وَفِي الشَّاءِ فِي كُلِّ أَرْبَعِينَ شَاةً شَاةٌ إِلَى عِشْرِينَ وَمِائَةٍ فَإِذَا زَادَتْ فَشَاتَانِ إِلَى مِائَتَيْنِ فَإِذَا زَادَتْ فَثَلاَثُ شِيَاهٍ إِلَى ثَلاَثِمِائَةِ شَاةٍ فَإِذَا زَادَتْ عَلَى ثَلاَثِمِائَةِ شَاةٍ فَفِي كُلِّ مِائَةِ شَاةٍ شَاةٌ ثُمَّ لَيْسَ فِيهَا شَيْءٌ حَتَّى تَبْلُغَ أَرْبَعَمِائَةٍ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ مَخَافَةَ الصَّدَقَةِ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بِالسَّوِيَّةِ وَلاَ يُؤْخَذُ فِي الصَّدَقَةِ هَرِمَةٌ وَلاَ ذَاتُ عَيْبٍ ‏"‏ ‏.‏ وَقَالَ الزُّهْرِيُّ إِذَا جَاءَ الْمُصَدِّقُ قَسَّمَ الشَّاءَ أَثْلاَثًا ثُلُثٌ خِيَارٌ وَثُلُثٌ أَوْسَاطٌ وَثُلُثٌ شِرَارٌ وَأَخَذَ الْمُصَدِّقُ مِنَ الْوَسَطِ ‏.‏ وَلَمْ يَذْكُرِ الزُّهْرِيُّ الْبَقَرَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ وَبَهْزِ بْنِ حَكِيمٍ عَنْ أَبِيهِ عَنْ جَدِّهِ ‏.‏ وَأَبِي ذَرٍّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ عَامَّةِ الْفُقَهَاءِ ‏.‏ وَقَدْ رَوَى يُونُسُ بْنُ يَزِيدَ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ هَذَا الْحَدِيثَ وَلَمْ يَرْفَعُوهُ وَإِنَّمَا رَفَعَهُ سُفْيَانُ بْنُ حُسَيْنٍ ‏.‏\hadithno{621}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Az-Zuhri narrated from Salim from his father:"The Messenger of Allah had a letter written about charity, but he had not dispatched it to his governors until he died; he kept it with him along with his sword. When he died, Abu Bakr implemented it until he died, as did Umar until he died. In it was: 'A sheep (is due) on five camels, two sheeps on ten, three sheeps on fifteen, four sheeps for twenty, a Bint Makhad on twenty-five to thirty-five. When it is more than that, then a Bint Labun, (is due, till the number of the camels reaches) forty-five. When it is more than that, then a Hiqqah until sixty. When it is more than that, then a Jadhah until seventy-five. When it is more than one hundred and twenty, then a Hiqqah on every fifty, and a Bint Labun on every forty. For sheep; one sheep (is due) for every forty sheeps until one hundred and twenty. When it is more than that, then two sheeps until two hundred. When it is more than that, then three sheeps until three hundred sheep. When it is more than three hundred sheep, then a sheep on every hundred sheep. Then there is nothing until it reaches four hundred. There is no combining the (property of) individuals nor separating the collective (property) fearing Sadaqah. And fr whatever is mixed together that two own, then they are to refer to the total. Neither an old or defective (animal) may be taken for charity}}
\hadithdefcmd{tirmidhi}{622}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ خُصَيْفٍ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي ثَلاَثِينَ مِنَ الْبَقَرِ تَبِيعٌ أَوْ تَبِيعَةٌ وَفِي أَرْبَعِينَ مُسِنَّةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ مُعَاذِ بْنِ جَبَلٍ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَاهُ عَبْدُ السَّلاَمِ بْنُ حَرْبٍ عَنْ خُصَيْفٍ وَعَبْدُ السَّلاَمِ ثِقَةٌ حَافِظٌ ‏.‏ وَرَوَى شَرِيكٌ هَذَا الْحَدِيثَ عَنْ خُصَيْفٍ عَنْ أَبِي عُبَيْدَةَ عَنْ أُمِّهِ عَنْ عَبْدِ اللَّهِ ‏.‏ وَأَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ لَمْ يَسْمَعْ مِنْ عَبْدِ اللَّهِ ‏.‏\hadithno{622}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that :the Prophet said: "A Tabi or a Tabi'ah (is due) on thirty cows, and a Musinnah (is due) on every forty}}
\hadithdefcmd{tirmidhi}{623}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم إِلَى الْيَمَنِ فَأَمَرَنِي أَنْ آخُذَ مِنْ كُلِّ ثَلاَثِينَ بَقَرَةً تَبِيعًا أَوْ تَبِيعَةً وَمِنْ كُلِّ أَرْبَعِينَ مُسِنَّةً وَمِنْ كُلِّ حَالِمٍ دِينَارًا أَوْ عِدْلَهُ مَعَافِرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ عَنِ الأَعْمَشِ عَنْ أَبِي وَائِلٍ عَنْ مَسْرُوقٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ فَأَمَرَهُ أَنْ يَأْخُذَ ‏.‏ وَهَذَا أَصَحُّ ‏.‏\hadithno{623}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal narrated:"The Prophet sent me to Yemen and ordered me to collect a Tabi or a Tabi'ah on every thirty cows, a Musinnah on every forty, a Dinar for every Halim, or its equivalent of Ma'afir."Abu Eisa said: This Hadith is Hasan. Some of them reported this Hadith from Sufyan, from Al-A'mash, from Abu Wa'il, from Masruq: "The Prophet sent Mu'adh to Yemen and ordered him to take..." and this is more authentic}}
\hadithdefcmd{tirmidhi}{624}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ عَنْ عَمْرِو بْنِ مُرَّةَ قَالَ سَأَلْتُ أَبَا عُبَيْدَةَ بْنَ عَبْدِ اللَّهِ هَلْ تَذْكُرُ مِنْ عَبْدِ اللَّهِ شَيْئًا قَالَ لاَ ‏.‏\hadithno{624}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Bash-shar (Al-Abdi) narrated to us, :Muhammad bin Ja'far narrated to us, from Shu'bah, from Amr bin Murrah who said: "I asked Abu Ubaidah bin Abdullah: 'Did you remember anything from Abdullah?' He said, 'No}}
\hadithdefcmd{tirmidhi}{625}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ الْمَكِّيُّ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ أَبِي مَعْبَدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مُعَاذًا إِلَى الْيَمَنِ فَقَالَ لَهُ ‏ "‏ إِنَّكَ تَأْتِي قَوْمًا أَهْلَ كِتَابٍ فَادْعُهُمْ إِلَى شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ خَمْسَ صَلَوَاتٍ فِي الْيَوْمِ وَاللَّيْلَةِ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَأَعْلِمْهُمْ أَنَّ اللَّهَ افْتَرَضَ عَلَيْهِمْ صَدَقَةً فِي أَمْوَالِهِمْ تُؤْخَذُ مِنْ أَغْنِيَائِهِمْ وَتُرَدُّ عَلَى فُقَرَائِهِمْ فَإِنْ هُمْ أَطَاعُوا لِذَلِكَ فَإِيَّاكَ وَكَرَائِمَ أَمْوَالِهِمْ وَاتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّهَا لَيْسَ بَيْنَهَا وَبَيْنَ اللَّهِ حِجَابٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الصُّنَابِحِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو مَعْبَدٍ مَوْلَى ابْنِ عَبَّاسٍ اسْمُهُ نَافِذٌ ‏.‏\hadithno{625}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated that :the Messenger of Allah sent Mu'adh to Yemen and said to him: "You are going to a people from the People of the Book, so invite them to testify that none has the right to be worshipped but Allah, and that I am the Messenger of Allah. If they comply with that, then inform them that Allah has made five prayers obligatory upon them in a day and a night. If they comply with that, then inform then that Allah has ordained a charity upon their wealth, which is to be taken from the rich among them and given to the poor among them. If they comply with that, then beware of their most precious wealth, and protect yourself from the supplication of the oppressed, for there is no barrier between it and Allah}}
\hadithdefcmd{tirmidhi}{626}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{626}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :the Prophet said: "There is no charity due on less than five camels, and there is no charity due on what is less than five Uqiyah (of silver), and there is no charity due on what is less than five Wasaq}}
\hadithdefcmd{tirmidhi}{627}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، وَشُعْبَةُ، وَمَالِكُ بْنُ أَنَسٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ عَبْدِ الْعَزِيزِ عَنْ عَمْرِو بْنِ يَحْيَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنْ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ ‏.‏ وَالْوَسْقُ سِتُّونَ صَاعًا وَخَمْسَةُ أَوْسُقٍ ثَلاَثُمِائَةِ صَاعٍ وَصَاعُ النَّبِيِّ صلى الله عليه وسلم خَمْسَةُ أَرْطَالٍ وَثُلُثٌ وَصَاعُ أَهْلِ الْكُوفَةِ ثَمَانِيَةُ أَرْطَالٍ ‏.‏ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ وَالأُوقِيَّةُ أَرْبَعُونَ دِرْهَمًا وَخَمْسُ أَوَاقٍ مِائَتَا دِرْهَمٍ ‏.‏ وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ يَعْنِي لَيْسَ فِيمَا دُونَ خَمْسٍ مِنَ الإِبِلِ صَدَقَةٌ فَإِذَا بَلَغَتْ خَمْسًا وَعِشْرِينَ مِنَ الإِبِلِ فَفِيهَا بِنْتُ مَخَاضٍ وَفِيمَا دُونَ خَمْسٍ وَعِشْرِينَ مِنَ الإِبِلِ فِي كُلِّ خَمْسٍ مِنَ الإِبِلِ شَاةٌ ‏.‏\hadithno{627}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{(Another chain of narration that) Abu Sa'eed Al-Khudri narrated that :the Prophet said (similar t Hadith no)}}
\hadithdefcmd{tirmidhi}{628}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَمَحْمُودُ بْنُ غَيْلاَنَ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، وَشُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي فَرَسِهِ وَلاَ فِي عَبْدِهِ صَدَقَةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ لَيْسَ فِي الْخَيْلِ السَّائِمَةِ صَدَقَةٌ وَلاَ فِي الرَّقِيقِ إِذَا كَانُوا لِلْخِدْمَةِ صَدَقَةٌ إِلاَّ أَنْ يَكُونُوا لِلتِّجَارَةِ فَإِذَا كَانُوا لِلتِّجَارَةِ فَفِي أَثْمَانِهِمُ الزَّكَاةُ إِذَا حَالَ عَلَيْهَا الْحَوْلُ ‏.‏\hadithno{628}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "There is no charity due from a Muslim for his horse nor his slave}}
\hadithdefcmd{tirmidhi}{629}{حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ التِّنِّيسِيُّ، عَنْ صَدَقَةَ بْنِ عَبْدِ اللَّهِ، عَنْ مُوسَى بْنِ يَسَارٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي الْعَسَلِ فِي كُلِّ عَشَرَةِ أَزُقٍّ زِقٌّ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَيَّارَةَ الْمُتَعِيِّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ فِي إِسْنَادِهِ مَقَالٌ وَلاَ يَصِحُّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ كَبِيرُ شَيْءٍ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ فِي الْعَسَلِ شَيْءٌ ‏.‏ وَصَدَقَةُ بْنُ عَبْدِ اللَّهِ لَيْسَ بِحَافِظٍ وَقَدْ خُولِفَ صَدَقَةُ بْنُ عَبْدِ اللَّهِ فِي رِوَايَةِ هَذَا الْحَدِيثِ عَنْ نَافِعٍ ‏.‏\hadithno{629}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated that :the Messenger of Allah said: "A Ziqq is due for every ten Ziqq of honey}}
\hadithdefcmd{tirmidhi}{630}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ عَنْ نَافِعٍ قَالَ سَأَلَنِي عُمَرُ بْنُ عَبْدِ الْعَزِيزِ عَنْ صَدَقَةِ الْعَسَلِ ‏.‏ قَالَ قُلْتُ مَا عِنْدَنَا عَسَلٌ نَتَصَدَّقُ مِنْهُ وَلَكِنْ أَخْبَرَنَا الْمُغِيرَةُ بْنُ حَكِيمٍ أَنَّهُ قَالَ لَيْسَ فِي الْعَسَلِ صَدَقَةٌ ‏.‏ فَقَالَ عُمَرُ عَدْلٌ مَرْضِيٌّ ‏.‏ فَكَتَبَ إِلَى النَّاسِ أَنْ تُوضَعَ ‏.‏ يَعْنِي عَنْهُمْ ‏.‏\hadithno{630}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ubaidulah bin Umar narrated that :Nafi said: "Umar bin Adbul-Aziz asked me about charity due on honey, so I said to him: 'We do not have honey that we could give charity from, but Al-Mughirah bin Hakim informed us that he (pbuh) said: 'There is no charity due on honey.' So Umar said: 'That is fair enough for me.' So he wrote to the people that is be lifted, meaning (the duty of paying it) from them}}
\hadithdefcmd{tirmidhi}{631}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا هَارُونُ بْنُ صَالِحٍ الطَّلْحِيُّ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَفَادَ مَالاً فَلاَ زَكَاةَ عَلَيْهِ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ عِنْدَ رَبِّهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَرَّاءَ بِنْتِ نَبْهَانَ الْغَنَوِيَّةِ ‏.‏\hadithno{631}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that :the Messenger of Allah said: "Whoever acquired wealth, then there is no Zakat on it until the Hawl has passed (while it is in his possession)}}
\hadithdefcmd{tirmidhi}{632}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَنِ اسْتَفَادَ مَالاً فَلاَ زَكَاةَ فِيهِ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ عِنْدَ رَبِّهِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ أَسْلَمَ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى أَيُّوبُ وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُ وَاحِدٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مَوْقُوفًا ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ ضَعِيفٌ فِي الْحَدِيثِ ضَعَّفَهُ أَحْمَدُ بْنُ حَنْبَلٍ وَعَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُهُمَا مِنْ أَهْلِ الْحَدِيثِ وَهُوَ كَثِيرُ الْغَلَطِ ‏.‏ وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنْ لاَ زَكَاةَ فِي الْمَالِ الْمُسْتَفَادِ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ ‏.‏ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا كَانَ عِنْدَهُ مَالٌ تَجِبُ فِيهِ الزَّكَاةُ فَفِيهِ الزَّكَاةُ وَإِنْ لَمْ يَكُنْ عِنْدَهُ سِوَى الْمَالِ الْمُسْتَفَادِ مَا تَجِبُ فِيهِ الزَّكَاةُ لَمْ يَجِبْ عَلَيْهِ فِي الْمَالِ الْمُسْتَفَادِ زَكَاةٌ حَتَّى يَحُولَ عَلَيْهِ الْحَوْلُ فَإِنِ اسْتَفَادَ مَالاً قَبْلَ أَنْ يَحُولَ عَلَيْهِ الْحَوْلُ فَإِنَّهُ يُزَكِّي الْمَالَ الْمُسْتَفَادَ مَعَ مَالِهِ الَّذِي وَجَبَتْ فِيهِ الزَّكَاةُ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَأَهْلُ الْكُوفَةِ ‏.‏\hadithno{632}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Bashar Awad Maarouf: Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar said:"Whoever acquired wealth, then there is no Zakat on it until the Hawl has passed while it is in his possession}}
\hadithdefcmd{tirmidhi}{633}{حَدَّثَنَا يَحْيَى بْنُ أَكْثَمَ، حَدَّثَنَا جَرِيرٌ، عَنْ قَابُوسِ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصْلُحُ قِبْلَتَانِ فِي أَرْضٍ وَاحِدَةٍ وَلَيْسَ عَلَى الْمُسْلِمِينَ جِزْيَةٌ ‏"‏ ‏.‏\hadithno{633}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that :the Messenger of Allah said: "Two Qiblahs in one land are of no benefit, and there is no Jizyah upon the Muslims}}
\hadithdefcmd{tirmidhi}{634}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ قَابُوسَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَفِي الْبَابِ عَنْ سَعِيدِ بْنِ زَيْدٍ، وَجَدِّ حَرْبِ بْنِ عُبَيْدِ اللَّهِ الثَّقَفِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ قَدْ رُوِيَ عَنْ قَابُوسِ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ أَنَّ النَّصْرَانِيَّ إِذَا أَسْلَمَ وُضِعَتْ عَنْهُ جِزْيَةُ رَقَبَتِهِ ‏.‏ وَقَوْلُ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لَيْسَ عَلَى الْمُسْلِمِينَ عُشُورٌ ‏"‏ إِنَّمَا يَعْنِي بِهِ جِزْيَةَ الرَّقَبَةِ وَفِي الْحَدِيثِ مَا يُفَسِّرُ هَذَا حَيْثُ قَالَ ‏"‏ إِنَّمَا الْعُشُورُ عَلَى الْيَهُودِ وَالنَّصَارَى وَلَيْسَ عَلَى الْمُسْلِمِينَ عُشُورٌ ‏"‏ ‏.‏\hadithno{634}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:(A similar narration as no)}}
\hadithdefcmd{tirmidhi}{635}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ بْنِ الْمُصْطَلِقِ، عَنِ ابْنِ أَخِي، زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَتْ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا مَعْشَرَ النِّسَاءِ تَصَدَّقْنَ وَلَوْ مِنْ حُلِيِّكُنَّ فَإِنَّكُنَّ أَكْثَرُ أَهْلِ جَهَنَّمَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{635}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Amr bin Al-Harith bin Al-Mustaliq narrated from the nephew of Zainab, the wife of Abdullah (Ibn Mas'ud) who said:"The Messenger of Allah delivered a sermon to us, and said: 'O you women! Give charity, even if it is from your jewelry, for indeed you will make up most of the people of Hell on the Day of Judgment}}
\hadithdefcmd{tirmidhi}{636}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ عَمْرِو بْنِ الْحَارِثِ ابْنِ أَخِي، زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ - عَنْ زَيْنَبَ، - امْرَأَةِ عَبْدِ اللَّهِ - عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي مُعَاوِيَةَ وَأَبُو مُعَاوِيَةَ وَهِمَ فِي حَدِيثِهِ فَقَالَ عَنْ عَمْرِو بْنِ الْحَارِثِ عَنِ ابْنِ أَخِي زَيْنَبَ ‏.‏ وَالصَّحِيحُ إِنَّمَا هُوَ عَنْ عَمْرِو بْنِ الْحَارِثِ ابْنِ أَخِي زَيْنَبَ ‏.‏ وَقَدْ رُوِيَ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَأَى فِي الْحُلِيِّ زَكَاةً ‏.‏ وَفِي إِسْنَادِ هَذَا الْحَدِيثِ مَقَالٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي ذَلِكَ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ فِي الْحُلِيِّ زَكَاةَ مَا كَانَ مِنْهُ ذَهَبٌ وَفِضَّةٌ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ ‏.‏ وَقَالَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمُ ابْنُ عُمَرَ وَعَائِشَةُ وَجَابِرُ بْنُ عَبْدِ اللَّهِ وَأَنَسُ بْنُ مَالِكٍ لَيْسَ فِي الْحُلِيِّ زَكَاةٌ ‏.‏ وَهَكَذَا رُوِيَ عَنْ بَعْضِ فُقَهَاءِ التَّابِعِينَ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{636}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Amr bin Al-Harith, the nephew of Zainab, the wife of Abdullah, narrated that :Zainab, the wife of Abdullah narrated similarly from the Prophet}}
\hadithdefcmd{tirmidhi}{637}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ امْرَأَتَيْنِ، أَتَتَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَفِي أَيْدِيهِمَا سُوَارَانِ مِنْ ذَهَبٍ فَقَالَ لَهُمَا ‏"‏ أَتُؤَدِّيَانِ زَكَاتَهُ ‏"‏ ‏.‏ قَالَتَا لاَ ‏.‏ قَالَ فَقَالَ لَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتُحِبَّانِ أَنْ يُسَوِّرَكُمَا اللَّهُ بِسُوَارَيْنِ مِنْ نَارٍ ‏"‏ ‏.‏ قَالَتَا لاَ ‏.‏ قَالَ ‏"‏ فَأَدِّيَا زَكَاتَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ قَدْ رَوَاهُ الْمُثَنَّى بْنُ الصَّبَّاحِ عَنْ عَمْرِو بْنِ شُعَيْبٍ نَحْوَ هَذَا ‏.‏ وَالْمُثَنَّى بْنُ الصَّبَّاحِ وَابْنُ لَهِيعَةَ يُضَعَّفَانِ فِي الْحَدِيثِ وَلاَ يَصِحُّ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْءٌ ‏.‏\hadithno{637}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, :that two women came to the Messenger of Allah, and they each had a bracelet of gold on their forearms. So he said to them: "Have you paid their Zakat?" They said, "No." The Messenger of Allah said to them: "Would you like for Allah to fashion then into two bracelets of Fire?" They said, "No." He said: "Then pay its Zakat}}
\hadithdefcmd{tirmidhi}{638}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ الْحَسَنِ بْنِ عُمَارَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عُبَيْدٍ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ مُعَاذٍ، أَنَّهُ كَتَبَ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْأَلُهُ عَنِ الْخُضْرَوَاتِ وَهِيَ الْبُقُولُ فَقَالَ ‏ "‏ لَيْسَ فِيهَا شَيْءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى إِسْنَادُ هَذَا الْحَدِيثِ لَيْسَ بِصَحِيحٍ وَلَيْسَ يَصِحُّ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْءٌ وَإِنَّمَا يُرْوَى هَذَا عَنْ مُوسَى بْنِ طَلْحَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنْ لَيْسَ فِي الْخُضْرَوَاتِ صَدَقَةٌ ‏.‏ قَالَ أَبُو عِيسَى وَالْحَسَنُ هُوَ ابْنُ عُمَارَةَ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ضَعَّفَهُ شُعْبَةُ وَغَيْرُهُ وَتَرَكَهُ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ ‏.‏\hadithno{638}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Eisa bin Talhah narrated that :Mu'adh had written to the Prophet to ask him about greens - which is "herbs" - so he (pbuh) said, "There is nothing due on them}}
\hadithdefcmd{tirmidhi}{639}{حَدَّثَنَا أَبُو مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا عَاصِمُ بْنُ عَبْدِ الْعَزِيزِ الْمَدَنِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، وَبُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِيمَا سَقَتِ السَّمَاءُ وَالْعُيُونُ الْعُشْرُ وَفِيمَا سُقِيَ بِالنَّضْحِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ وَبُسْرِ بْنِ سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَكَأَنَّ هَذَا أَصَحُّ ‏.‏ وَقَدْ صَحَّ حَدِيثُ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ وَعَلَيْهِ الْعَمَلُ عِنْدَ عَامَّةِ الْفُقَهَاءِ ‏.‏\hadithno{639}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "For what is watered by the heavens and steams, the Ushr is due, and for what is watered by irrigation, half of the Ushr}}
\hadithdefcmd{tirmidhi}{640}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سَنَّ فِيمَا سَقَتِ السَّمَاءُ وَالْعُيُونُ أَوْ كَانَ عَثَرِيًّا الْعُشْرُ وَفِيمَا سُقِيَ بِالنَّضْحِ نِصْفُ الْعُشْرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{640}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Salim narrated from his father that :the Messenger of Allah instituted the Ushr of what was watered by the heavens and steams, or through natural channels, and half of the Ushr for what is watered by irrigation}}
\hadithdefcmd{tirmidhi}{641}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الْمُثَنَّى بْنِ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ النَّاسَ فَقَالَ ‏ "‏ أَلاَ مَنْ وَلِيَ يَتِيمًا لَهُ مَالٌ فَلْيَتَّجِرْ فِيهِ وَلاَ يَتْرُكْهُ حَتَّى تَأْكُلَهُ الصَّدَقَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا رُوِيَ هَذَا الْحَدِيثُ مِنْ هَذَا الْوَجْهِ وَفِي إِسْنَادِهِ مَقَالٌ لأَنَّ الْمُثَنَّى بْنَ الصَّبَّاحِ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ شُعَيْبٍ أَنَّ عُمَرَ بْنَ الْخَطَّابِ ‏.‏ فَذَكَرَ هَذَا الْحَدِيثَ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا الْبَابِ فَرَأَى غَيْرُ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي مَالِ الْيَتِيمِ زَكَاةً ‏.‏ مِنْهُمْ عُمَرُ وَعَلِيٌّ وَعَائِشَةُ وَابْنُ عُمَرَ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَتْ طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ لَيْسَ فِي مَالِ الْيَتِيمِ زَكَاةٌ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ ‏.‏ وَعَمْرُو بْنُ شُعَيْبٍ هُوَ ابْنُ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ وَشُعَيْبٌ قَدْ سَمِعَ مِنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَقَدْ تَكَلَّمَ يَحْيَى بْنُ سَعِيدٍ فِي حَدِيثِ عَمْرِو بْنِ شُعَيْبٍ وَقَالَ هُوَ عِنْدَنَا وَاهٍ ‏.‏ وَمَنْ ضَعَّفَهُ فَإِنَّمَا ضَعَّفَهُ مِنْ قِبَلِ أَنَّهُ يُحَدِّثُ مِنْ صَحِيفَةِ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَمَّا أَكْثَرُ أَهْلِ الْحَدِيثِ فَيَحْتَجُّونَ بِحَدِيثِ عَمْرِو بْنِ شُعَيْبٍ وَيُثْبِتُونَهُ مِنْهُمْ أَحْمَدُ وَإِسْحَاقُ وَغَيْرُهُمَا ‏.‏\hadithno{641}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather that :the Prophet addressed the people and said: "As for one who is the guardian of an orphan who has wealth, then let him do business with it and not leave it until it becomes consumed by charity}}
\hadithdefcmd{tirmidhi}{642}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَجْمَاءُ جُرْحُهَا جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَالْبِئْرُ جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعُبَادَةَ بْنِ الصَّامِتِ وَعَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{642}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "The injuries caused by the animal are without liability, and mines are without liability, and wells are without liability, and the Khumus is due on Rikaz}}
\hadithdefcmd{tirmidhi}{643}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ مَسْعُودِ بْنِ نِيَارٍ، يَقُولُ جَاءَ سَهْلُ بْنُ أَبِي حَثْمَةَ إِلَى مَجْلِسِنَا فَحَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ إِذَا خَرَصْتُمْ فَخُذُوا وَدَعُوا الثُّلُثَ فَإِنْ لَمْ تَدَعُوا الثُّلُثَ فَدَعُوا الرُّبُعَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَتَّابِ بْنِ أَسِيدٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى حَدِيثِ سَهْلِ بْنِ أَبِي حَثْمَةَ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ فِي الْخَرْصِ وَبِحَدِيثِ سَهْلِ بْنِ أَبِي حَثْمَةَ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَالْخَرْصُ إِذَا أَدْرَكَتِ الثِّمَارُ مِنَ الرُّطَبِ وَالْعِنَبِ مِمَّا فِيهِ الزَّكَاةُ بَعَثَ السُّلْطَانُ خَارِصًا يَخْرُصُ عَلَيْهِمْ ‏.‏ وَالْخَرْصُ أَنْ يَنْظُرَ مَنْ يُبْصِرُ ذَلِكَ فَيَقُولُ يَخْرُجُ مِنْ هَذَا مِنَ الزَّبِيبِ كَذَا وَكَذَا وَمِنَ التَّمْرِ كَذَا وَكَذَا فَيُحْصَى عَلَيْهِمْ وَيَنْظُرُ مَبْلَغَ الْعُشْرِ مِنْ ذَلِكَ فَيُثْبِتُ عَلَيْهِمْ ثُمَّ يُخَلِّي بَيْنَهُمْ وَبَيْنَ الثِّمَارِ فَيَصْنَعُونَ مَا أَحَبُّوا فَإِذَا أَدْرَكَتِ الثِّمَارُ أُخِذَ مِنْهُمُ الْعُشْرُ ‏.‏ هَكَذَا فَسَّرَهُ بَعْضُ أَهْلِ الْعِلْمِ وَبِهَذَا يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{643}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdur-Rahman bin Mas'ud bin Niyar said:"Sahl bin Abi Hathmah came to a gathering of ours, and he narrated that the Messenger of Allah would say: "When you make an assessment, then take it and leave a third, if you do not leave a third, then leave a quarter}}
\hadithdefcmd{tirmidhi}{644}{حَدَّثَنَا أَبُو عَمْرٍو، مُسْلِمُ بْنُ عَمْرٍو الْحَذَّاءُ الْمَدَنِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، عَنْ مُحَمَّدِ بْنِ صَالِحٍ التَّمَّارِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَتَّابِ بْنِ أَسِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَبْعَثُ عَلَى النَّاسِ مَنْ يَخْرُصُ عَلَيْهِمْ كُرُومَهُمْ وَثِمَارَهُمْ ‏.‏ وَبِهَذَا الإِسْنَادِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي زَكَاةِ الْكُرُومِ ‏ "‏ إِنَّهَا تُخْرَصُ كَمَا يُخْرَصُ النَّخْلُ ثُمَّ تُؤَدَّى زَكَاتُهُ زَبِيبًا كَمَا تُؤَدَّى زَكَاةُ النَّخْلِ تَمْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى ابْنُ جُرَيْجٍ هَذَا الْحَدِيثَ عَنِ ابْنِ شِهَابٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ حَدِيثُ ابْنِ جُرَيْجٍ غَيْرُ مَحْفُوظٍ وَحَدِيثُ ابْنِ الْمُسَيَّبِ عَنْ عَتَّابِ بْنِ أَسِيدٍ أَثْبَتُ وَأَصَحُّ ‏.‏\hadithno{644}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Attab bin Asid narrated that :the Prophet said about Zakat on grapevines: "They are to be assessed just as the date-palm is assessed. Then its Zakat is paid in raisins just as the Zakat for the date-palm is paid in dried dates}}
\hadithdefcmd{tirmidhi}{645}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا يَزِيدُ بْنُ عِيَاضٍ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعَامِلُ عَلَى الصَّدَقَةِ بِالْحَقِّ كَالْغَازِي فِي سَبِيلِ اللَّهِ حَتَّى يَرْجِعَ إِلَى بَيْتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ رَافِعِ بْنِ خَدِيجٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيَزِيدُ بْنُ عِيَاضٍ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَحَدِيثُ مُحَمَّدِ بْنِ إِسْحَاقَ أَصَحُّ ‏.‏\hadithno{645}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Rafi bin Khadij narrated:"I herd the Messenger of Allah saying: 'The one who works in collecting charity in truth is like the one who fights in the cause of Allah until he returns}}
\hadithdefcmd{tirmidhi}{646}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُعْتَدِي فِي الصَّدَقَةِ كَمَانِعِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأُمِّ سَلَمَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ أَحْمَدُ بْنُ حَنْبَلٍ فِي سَعْدِ بْنِ سِنَانٍ ‏.‏ وَهَكَذَا يَقُولُ اللَّيْثُ بْنُ سَعْدٍ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ عَنْ سَعْدِ بْنِ سِنَانٍ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏ وَيَقُولُ عَمْرُو بْنُ الْحَارِثِ وَابْنُ لَهِيعَةَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ عَنْ سِنَانِ بْنِ سَعْدٍ عَنْ أَنَسٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ وَالصَّحِيحُ سِنَانُ بْنُ سَعْدٍ ‏.‏ وَقَوْلُهُ ‏"‏ الْمُعْتَدِي فِي الصَّدَقَةِ كَمَانِعِهَا ‏"‏ يَقُولُ عَلَى الْمُعْتَدِي مِنَ الإِثْمِ كَمَا عَلَى الْمَانِعِ إِذَا مَنَعَ ‏.‏\hadithno{646}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "The one who commits transgression with charity is like the one who does not pay it}}
\hadithdefcmd{tirmidhi}{647}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ يَزِيدَ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَاكُمُ الْمُصَدِّقُ فَلاَ يُفَارِقَنَّكُمْ إِلاَّ عَنْ رِضًا ‏"‏ ‏.‏\hadithno{647}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jarir narrated that :the Prophet said: "When the charity collector comes to you, then he should not depart from you except while pleased}}
\hadithdefcmd{tirmidhi}{648}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ دَاوُدَ عَنِ الشَّعْبِيِّ، أَصَحُّ مِنْ حَدِيثِ مُجَالِدٍ ‏.‏ وَقَدْ ضَعَّفَ مُجَالِدًا بَعْضُ أَهْلِ الْعِلْمِ وَهُوَ كَثِيرُ الْغَلَطِ ‏.‏\hadithno{648}\hadithgrade{Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jarir narrated :similar (narration to no. 647 with a different chain) from the Prophet}}
\hadithdefcmd{tirmidhi}{649}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ أَشْعَثَ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ قَدِمَ عَلَيْنَا مُصَدِّقُ النَّبِيِّ صلى الله عليه وسلم فَأَخَذَ الصَّدَقَةَ مِنْ أَغْنِيَائِنَا فَجَعَلَهَا فِي فُقَرَائِنَا وَكُنْتُ غُلاَمًا يَتِيمًا فَأَعْطَانِي مِنْهَا قَلُوصًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي جُحَيْفَةَ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{649}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Awn bin Abi Jubaitah narrated from his father:"The charity collector of the Prophet came to us. So he took the charity from our rich to our poor. I was a orphan boy, so he came to me and gave me a young she-camel from it}}
\hadithdefcmd{tirmidhi}{650}{حَدَّثَنَا قُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، - قَالَ قُتَيْبَةُ حَدَّثَنَا شَرِيكٌ، وَقَالَ، عَلِيٌّ أَخْبَرَنَا شَرِيكٌ، وَالْمَعْنَى، وَاحِدٌ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَأَلَ النَّاسَ وَلَهُ مَا يُغْنِيهِ جَاءَ يَوْمَ الْقِيَامَةِ وَمَسْأَلَتُهُ فِي وَجْهِهِ خُمُوشٌ أَوْ خُدُوشٌ أَوْ كُدُوحٌ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا يُغْنِيهِ قَالَ ‏"‏ خَمْسُونَ دِرْهَمًا أَوْ قِيمَتُهَا مِنَ الذَّهَبِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ تَكَلَّمَ شُعْبَةُ فِي حَكِيمِ بْنِ جُبَيْرٍ مِنْ أَجْلِ هَذَا الْحَدِيثِ ‏.‏\hadithno{650}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated that :the Messenger of Allah said: "Whoever begs from the people while he has what he needs, he will come on the Day of Judgment and his begging with be scratches or lacerations, or bite marks on his face." They said: "O Messenger of Allah! 'How much is it that one needs?' He said: 'Fifty Dirham, or their value in gold}}
\hadithdefcmd{tirmidhi}{651}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، بِهَذَا الْحَدِيثِ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُثْمَانَ صَاحِبُ شُعْبَةَ لَوْ غَيْرُ حَكِيمٍ حَدَّثَ بِهَذَا الْحَدِيثِ ‏.‏ فَقَالَ لَهُ سُفْيَانُ وَمَا لِحَكِيمٍ لاَ يُحَدِّثُ عَنْهُ شُعْبَةُ قَالَ نَعَمْ ‏.‏ قَالَ سُفْيَانُ سَمِعْتُ زُبَيْدًا يُحَدِّثُ بِهَذَا عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَصْحَابِنَا وَبِهِ يَقُولُ الثَّوْرِيُّ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالُوا إِذَا كَانَ عِنْدَ الرَّجُلِ خَمْسُونَ دِرْهَمًا لَمْ تَحِلَّ لَهُ الصَّدَقَةُ ‏.‏ قَالَ وَلَمْ يَذْهَبْ بَعْضُ أَهْلِ الْعِلْمِ إِلَى حَدِيثِ حَكِيمِ بْنِ جُبَيْرٍ وَوَسَّعُوا فِي هَذَا وَقَالُوا إِذَا كَانَ عِنْدَهُ خَمْسُونَ دِرْهَمًا أَوْ أَكْثَرُ وَهُوَ مُحْتَاجٌ فَلَهُ أَنْ يَأْخُذَ مِنَ الزَّكَاةِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَغَيْرِهِ مِنْ أَهْلِ الْفِقْهِ وَالْعِلْمِ ‏.‏\hadithno{651}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Mahmud bin Ghaydin narrated to us:Yahya bin Adam narrated to us, Sufyan narrated this Hadith to us from Hakim bin Jubair. So Abdullah bin Uthman, the companion of Shu'bah said to him (Sufyan): "If only someone besides Hakim had narrated this (Hadith)." Sufyan said to him, "So what is with Hakim; Shu'bah would not narrate from him?" He said: "Yes." So Sufyan said: "I heard Zubaid narrating this from Muhammad bin Abdur-Rahman bin Yazid}}
\hadithdefcmd{tirmidhi}{652}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، ح وَحَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ رَيْحَانَ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَحِلُّ الصَّدَقَةُ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَحُبْشِيِّ بْنِ جُنَادَةَ وَقَبِيصَةَ بْنِ مُخَارِقٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ هَذَا الْحَدِيثَ بِهَذَا الإِسْنَادِ وَلَمْ يَرْفَعْهُ ‏.‏ وَقَدْ رُوِيَ فِي غَيْرِ هَذَا الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تَحِلُّ الْمَسْأَلَةُ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ ‏"‏ ‏.‏ وَإِذَا كَانَ الرَّجُلُ قَوِيًّا مُحْتَاجًا وَلَمْ يَكُنْ عِنْدَهُ شَيْءٌ فَتُصُدِّقَ عَلَيْهِ أَجْزَأَ عَنِ الْمُتَصَدِّقِ عِنْدَ أَهْلِ الْعِلْمِ وَوَجْهُ هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ عَلَى الْمَسْأَلَةِ ‏.‏\hadithno{652}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Amr narrated that :the Prophet said: "Charity is not lawful for the rich nor for the physically fit}}
\hadithdefcmd{tirmidhi}{653}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ حُبْشِيِّ بْنِ جُنَادَةَ السَّلُولِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَهُوَ وَاقِفٌ بِعَرَفَةَ أَتَاهُ أَعْرَابِيٌّ فَأَخَذَ بِطَرَفِ رِدَائِهِ فَسَأَلَهُ إِيَّاهُ فَأَعْطَاهُ وَذَهَبَ فَعِنْدَ ذَلِكَ حَرُمَتِ الْمَسْأَلَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَسْأَلَةَ لاَ تَحِلُّ لِغَنِيٍّ وَلاَ لِذِي مِرَّةٍ سَوِيٍّ إِلاَّ لِذِي فَقْرٍ مُدْقِعٍ أَوْ غُرْمٍ مُفْظِعٍ وَمَنْ سَأَلَ النَّاسَ لِيُثْرِيَ بِهِ مَالَهُ كَانَ خُمُوشًا فِي وَجْهِهِ يَوْمَ الْقِيَامَةِ وَرَضْفًا يَأْكُلُهُ مِنْ جَهَنَّمَ فَمَنْ شَاءَ فَلْيُقِلَّ وَمَنْ شَاءَ فَلْيُكْثِرْ ‏"‏ ‏.‏\hadithno{653}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hubshi bin Junadah As-Saluli narrated:"During the Farewell Hajj, while the Messener of allah was standing at Arafat, a Bedouin came to him begging while pulling on the edge of his Rida. He gave him something and he left. With that, begging was made unlawful, so the Messenger of Allah said: 'Begging is not lawful for the rich nor for the physically fit, except for the one who is severely poor or in perilous debt. And whoever begs the people (merely) to increase his wealth, then on the Day of Judgment (the wealth he begged for) will be lacerations on his face and heated coals from Hell will be provided for him to eat. Whoever wishes, let him take a little, and whoever wishes, then let him take a lot}}
\hadithdefcmd{tirmidhi}{654}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ عَبْدِ الرَّحِيمِ بْنِ سُلَيْمَانَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{654}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrator mentioned in hadith:There is another chain with a similar narration}}
\hadithdefcmd{tirmidhi}{655}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا فَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقَ النَّاسُ عَلَيْهِ فَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِغُرَمَائِهِ ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَجُوَيْرِيَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{655}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"During the time of the Messenger of Allah, a man suffered a loss on fruits that he had sold, resulting in more debt. The Messenger of Allah said: 'Give him charity.' So the people gave him charity but it did not cover his debt. So the Messenger of Allah said to his debtors: 'Take what you have and there is nothing for you but that}}
\hadithdefcmd{tirmidhi}{656}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، وَيُوسُفُ بْنُ يَعْقُوبَ الضُّبَعِيُّ السَّدُوسِيُّ، قَالاَ حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أُتِيَ بِشَيْءٍ سَأَلَ ‏ "‏ أَصَدَقَةٌ هِيَ أَمْ هَدِيَّةٌ ‏"‏ ‏.‏ فَإِنْ قَالُوا صَدَقَةٌ لَمْ يَأْكُلْ وَإِنْ قَالُوا هَدِيَّةٌ أَكَلَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلْمَانَ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَالْحَسَنِ بْنِ عَلِيٍّ وَأَبِي عَمِيرَةَ جَدُّ مُعَرَّفِ بْنِ وَاصِلٍ وَاسْمُهُ رُشَيْدُ بْنُ مَالِكٍ وَمَيْمُونِ بْنِ مِهْرَانَ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي رَافِعٍ وَعَبْدِ الرَّحْمَنِ بْنِ عَلْقَمَةَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ أَيْضًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَلْقَمَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَقِيلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَجَدُّ بَهْزِ بْنِ حَكِيمٍ اسْمُهُ مُعَاوِيَةُ بْنُ حَيْدَةَ الْقُشَيْرِيُّ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ بَهْزِ بْنِ حَكِيمٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{656}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father, from his grandfather who said:"When something was brought to him, the Messenger of Allah would ask: 'Is this charity or a gift?' If they said: 'Charity.' He would not eat it, and if they said, 'A gift' he would eat it}}
\hadithdefcmd{tirmidhi}{657}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي رَافِعٍ، عَنْ أَبِي رَافِعٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ رَجُلاً مِنْ بَنِي مَخْزُومٍ عَلَى الصَّدَقَةِ فَقَالَ لأَبِي رَافِعٍ اصْحَبْنِي كَيْمَا تُصِيبَ مِنْهَا ‏.‏ فَقَالَ لاَ ‏.‏ حَتَّى آتِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَسْأَلَهُ ‏.‏ فَانْطَلَقَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ ‏ "‏ إِنَّ الصَّدَقَةَ لاَ تَحِلُّ لَنَا وَإِنَّ مَوَالِيَ الْقَوْمِ مِنْ أَنْفُسِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو رَافِعٍ مَوْلَى النَّبِيِّ صلى الله عليه وسلم اسْمُهُ أَسْلَمُ وَابْنُ أَبِي رَافِعٍ هُوَ عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ كَاتِبُ عَلِيِّ بْنِ أَبِي طَالِبٍ رضى الله عنه ‏.‏\hadithno{657}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Rafi (may Allah be pleased with him) narrated that :the Messenger of Allah sent a man from Banu Makhzun to collect charity, so he said to Abu Rafi: "Accompany me so that perhaps you may have some of it." So he said: "Not until I ask the Messenger of Allah." So he went to the Prophet to ask him, and he said: "Charity is not lawful for us, and to be the Mawda of a people to be the same as them}}
\hadithdefcmd{tirmidhi}{658}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ، عَنْ عَمِّهَا، سَلْمَانَ بْنِ عَامِرٍ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَفْطَرَ أَحَدُكُمْ فَلْيُفْطِرْ عَلَى تَمْرٍ فَإِنَّهُ بَرَكَةٌ فَإِنْ لَمْ يَجِدْ تَمْرًا فَالْمَاءُ فَإِنَّهُ طَهُورٌ ‏"‏ ‏.‏ وَقَالَ ‏"‏ الصَّدَقَةُ عَلَى الْمِسْكِينِ صَدَقَةٌ وَهِيَ عَلَى ذِي الرَّحِمِ ثِنْتَانِ صَدَقَةٌ وَصِلَةٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَلْمَانَ بْنِ عَامِرٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالرَّبَابُ هِيَ أُمُّ الرَّائِحِ بِنْتُ صُلَيْعٍ ‏.‏ وَهَكَذَا رَوَى سُفْيَانُ الثَّوْرِيُّ عَنْ عَاصِمٍ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنِ الرَّبَابِ عَنْ سَلْمَانَ بْنِ عَامِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا الْحَدِيثِ ‏.‏ وَرَوَى شُعْبَةُ عَنْ عَاصِمٍ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنْ سَلْمَانَ بْنِ عَامِرٍ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنِ الرَّبَابِ ‏.‏ وَحَدِيثُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ عُيَيْنَةَ أَصَحُّ ‏.‏ وَهَكَذَا رَوَى ابْنُ عَوْنٍ وَهِشَامُ بْنُ حَسَّانَ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنِ الرَّبَابِ عَنْ سَلْمَانَ بْنِ عَامِرٍ ‏.‏\hadithno{658}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Hafsah bint Sirin narrated from Ar-Rabab, from her uncle Salman bin Amir that he related that :the Prophet said: "When one of you breaks his fast, then let him do so with dried dates, for they are blessed. Whoever does not find dates, then water, for it is purifying." And he said: "Charity given to the needy is (counted as) charity, and if it is given to relatives it is (counted as) two: charity and nurturing (the ties of kinship)}}
\hadithdefcmd{tirmidhi}{659}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ مَدُّويَهْ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، عَنْ شَرِيكٍ، عَنْ أَبِي حَمْزَةَ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ سَأَلْتُ أَوْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الزَّكَاةِ فَقَالَ ‏"‏ إِنَّ فِي الْمَالِ لَحَقًّا سِوَى الزَّكَاةِ ‏"‏ ‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ الَّتِي فِي الْبَقَرَةِ ‏(‏ لَيْسَ الْبِرَّ أَنْ تُوَلُّوا وُجُوهَكُمْ ‏)‏ الآيَةَ ‏.‏\hadithno{659}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Fatimah bint Qais narrated that :she asked -or, the Prophet was asked - about Zakat, and he said: "Indeed there is a duty on wealthy aside from Zakat." Then he recited this Ayah which is in Al-Baqarah: 'It is not Al-Birr (piety, righteousness) that you turn your faces.' (Al-Baqarah 2:)}}
\hadithdefcmd{tirmidhi}{660}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُحَمَّدُ بْنُ الطُّفَيْلِ، عَنْ شَرِيكٍ، عَنْ أَبِي حَمْزَةَ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْمَالِ حَقًّا سِوَى الزَّكَاةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ لَيْسَ بِذَاكَ ‏.‏ وَأَبُو حَمْزَةَ مَيْمُونٌ الأَعْوَرُ يُضَعَّفُ ‏.‏ وَرَوَى بَيَانٌ وَإِسْمَاعِيلُ بْنُ سَالِمٍ عَنِ الشَّعْبِيِّ هَذَا الْحَدِيثَ قَوْلَهُ وَهَذَا أَصَحُّ ‏.‏\hadithno{660}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Fatimah bint Qais narrated that :the Prophet said: "Indeed there is a duty on wealth aside from Zakat}}
\hadithdefcmd{tirmidhi}{661}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ سَعِيدِ بْنِ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَصَدَّقَ أَحَدٌ بِصَدَقَةٍ مِنْ طَيِّبٍ وَلاَ يَقْبَلُ اللَّهُ إِلاَّ الطَّيِّبَ إِلاَّ أَخَذَهَا الرَّحْمَنُ بِيَمِينِهِ وَإِنْ كَانَتْ تَمْرَةً تَرْبُو فِي كَفِّ الرَّحْمَنِ حَتَّى تَكُونَ أَعْظَمَ مِنَ الْجَبَلِ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ فَصِيلَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَدِيِّ بْنِ حَاتِمٍ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى وَحَارِثَةَ بْنِ وَهْبٍ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَبُرَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{661}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "None gives charity from Tayyib - and Allah does not accept but Tayyib - but that Ar-Rahman accepts it with His Right (Hand). Even if it is a date, it is nurtured in the Hand of Ar-Rahman until it is greater than a mountain, just as one of you nurtures his foal or young camel}}
\hadithdefcmd{tirmidhi}{662}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، حَدَّثَنَا الْقَاسِمُ بْنُ مُحَمَّدٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ يَقْبَلُ الصَّدَقَةَ وَيَأْخُذُهَا بِيَمِينِهِ فَيُرَبِّيهَا لأَحَدِكُمْ كَمَا يُرَبِّي أَحَدُكُمْ مُهْرَهُ حَتَّى إِنَّ اللُّقْمَةَ لَتَصِيرُ مِثْلَ أُحُدٍ ‏"‏ ‏.‏ وَتَصْدِيقُ ذَلِكَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ ‏(‏وهُوَ الَّذِي يَقبَلُ التَّوبَةَ عَنْ عِبَادِهِ ‏)‏ ويَأْخُذُ الصَّدَقَاتِ‏‏ ‏(يَمْحَقُ الله الرَّبَا ويُرْبِي الصَّدَقَاتِ‏)‏‏.‏ قَالَ أَبُو عِيسَى: هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ. وَقَدْ رُوِيَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ نَحْوُ هَذَا. وَقَدْ قَالَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ فِي هَذَا الْحَدِيثِ وَمَا يُشْبِهُ هَذَا مِنَ الرِّوَايَاتِ مِنَ الصِّفَاتِ وَنُزُولِ الرَّبِّ تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا قَالُوا قَدْ تَثْبُتُ الرِّوَايَاتُ فِي هَذَا وَيُؤْمَنُ بِهَا وَلاَ يُتَوَهَّمُ وَلاَ يُقَالُ كَيْفَ هَكَذَا رُوِيَ عَنْ مَالِكٍ وَسُفْيَانَ بْنِ عُيَيْنَةَ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُمْ قَالُوا فِي هَذِهِ الأَحَادِيثِ أَمِرُّوهَا بِلاَ كَيْفٍ. وَهَكَذَا قَوْلُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ السُّنَّةِ وَالْجَمَاعَةِ. وَأَمَّا الْجَهْمِيَّةُ فَأَنْكَرَتْ هَذِهِ الرِّوَايَاتِ وَقَالُوا هَذَا تَشْبِيهٌ. وَقَدْ ذَكَرَ اللَّهُ عَزَّ وَجَلَّ فِي غَيْرِ مَوْضِعٍ مِنْ كِتَابِهِ الْيَدَ وَالسَّمْعَ وَالْبَصَرَ فَتَأَوَّلَتِ الْجَهْمِيَّةُ هَذِهِ الآيَاتِ فَفَسَّرُوهَا عَلَى غَيْرِ مَا فَسَّرَ أَهْلُ الْعِلْمِ وَقَالُوا إِنَّ اللَّهَ لَمْ يَخْلُقْ آدَمَ بِيَدِهِ. وَقَالُوا إِنَّ مَعْنَى الْيَدِ هَاهُنَا الْقُوَّةُ. وَقَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ إِنَّمَا يَكُونُ التَّشْبِيهُ إِذَا قَالَ يَدٌ كَيَدٍ أَوْ مِثْلُ يَدٍ أَوْ سَمْعٌ كَسَمْعٍ أَوْ مِثْلُ سَمْعٍ. فَإِذَا قَالَ سَمْعٌ كَسَمْعٍ أَوْ مِثْلُ سَمْعٍ فَهَذَا التَّشْبِيهُ وَأَمَّا إِذَا قَالَ كَمَا قَالَ اللَّهُ تَعَالَى يَدٌ وَسَمْعٌ وَبَصَرٌ وَلاَ يَقُولُ كَيْفَ وَلاَ يَقُولُ مِثْلُ سَمْعٍ وَلاَ كَسَمْعٍ فَهَذَا لاَ يَكُونُ تَشْبِيهًا وَهُوَ كَمَا قَالَ اللَّهُ تَعَالَى فِي كِتَابِهِ: \{لَيْسَ كَمِثْلِهِ شَيْءٌ وَهُوَ السَّمِيعُ الْبَصِيرُ\}\hadithno{662}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Indeed Allah accepts charity, and He accepts it with His Right (Hand) to nurture it for one of you, just like one of you would nuture his foal, until the bite (of food) becomes as large as Uhud." The Book of Allah, the Mighty and Sublime testifies to that: 'He accepts repentance from His worshipers, and accepts charity.'And: 'Allah will destroy Riba and give increase for charity.' (Abu Eisa) said: This Hadith is (Hasan) Sahih}}
\hadithdefcmd{tirmidhi}{663}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا صَدَقَةُ بْنُ مُوسَى، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَىُّ الصَّوْمِ أَفْضَلُ بَعْدَ رَمَضَانَ فَقَالَ ‏"‏ شَعْبَانُ لِتَعْظِيمِ رَمَضَانَ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏"‏ صَدَقَةٌ فِي رَمَضَانَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَصَدَقَةُ بْنُ مُوسَى لَيْسَ عِنْدَهُمْ بِذَاكَ الْقَوِيِّ ‏.‏\hadithno{663}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that :the Prophet was asked which fast was most virtuous after Ramadan? He said: "Sha'ban in honor of Ramadan" He said: "Which charity is best?" He (pbuh) said: "Charity in Ramadan}}
\hadithdefcmd{tirmidhi}{664}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عِيسَى الْخَزَّازُ الْبَصْرِيُّ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الصَّدَقَةَ لَتُطْفِئُ غَضَبَ الرَّبِّ وَتَدْفَعُ مِيتَةَ السُّوءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{664}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "Indeed charity extinguishes the Lord's anger and it protects against the evil death}}
\hadithdefcmd{tirmidhi}{665}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بُجَيْدٍ، عَنْ جَدَّتِهِ أُمِّ بُجَيْدٍ، - وَكَانَتْ مِمَّنْ بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم - أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ الْمِسْكِينَ لَيَقُومُ عَلَى بَابِي فَمَا أَجِدُ لَهُ شَيْئًا أُعْطِيهِ إِيَّاهُ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ لَمْ تَجِدِي شَيْئًا تُعْطِينَهُ إِيَّاهُ إِلاَّ ظِلْفًا مُحْرَقًا فَادْفَعِيهِ إِلَيْهِ فِي يَدِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَحُسَيْنِ بْنِ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ بُجَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{665}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin Bujaid narrated from his grandmother; :Umm Bujaid - and she was one of those who gave the pledge to the Prophet - she said to the Messenger of Allah: "There is a needy person who stands outside my door, but I cannot find anything to give to him." So the Messenger of Allah said to her: "If you do not find anything to give him except a burnt trotter then hand it over to him}}
\hadithdefcmd{tirmidhi}{666}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ أَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ وَإِنَّهُ لأَبْغَضُ الْخَلْقِ إِلَىَّ فَمَا زَالَ يُعْطِينِي حَتَّى إِنَّهُ لأَحَبُّ الْخَلْقِ إِلَىَّ ‏.‏ قَالَ أَبُو عِيسَى حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ بِهَذَا أَوْ شِبْهِهِ فِي الْمُذَاكَرَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ صَفْوَانَ رَوَاهُ مَعْمَرٌ وَغَيْرُهُ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ أَنَّ صَفْوَانَ بْنَ أُمَيَّةَ قَالَ أَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَكَأَنَّ هَذَا الْحَدِيثَ أَصَحُّ وَأَشْبَهُ إِنَّمَا هُوَ سَعِيدُ بْنُ الْمُسَيَّبِ أَنَّ صَفْوَانَ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي إِعْطَاءِ الْمُؤَلَّفَةِ قُلُوبُهُمْ فَرَأَى أَكْثَرُ أَهْلِ الْعِلْمِ أَنْ لاَ يُعْطَوْا ‏.‏ وَقَالُوا إِنَّمَا كَانُوا قَوْمًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَانَ يَتَأَلَّفُهُمْ عَلَى الإِسْلاَمِ حَتَّى أَسْلَمُوا ‏.‏ وَلَمْ يَرَوْا أَنْ يُعْطَوُا الْيَوْمَ مِنَ الزَّكَاةِ عَلَى مِثْلِ هَذَا الْمَعْنَى وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَغَيْرِهِمْ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُهُمْ مَنْ كَانَ الْيَوْمَ عَلَى مِثْلِ حَالِ هَؤُلاَءِ وَرَأَى الإِمَامُ أَنْ يَتَأَلَّفَهُمْ عَلَى الإِسْلاَمِ فَأَعْطَاهُمْ جَازَ ذَلِكَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{666}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa'eed bin Al-Musayyab narrated from Safwan bin Umayyah who said:"The Messenger of Allah gave to me on the Day of Hunain, and he was the most hated creature to me. But he did not stop giving to me until he was the most loved creature to me}}
\hadithdefcmd{tirmidhi}{667}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَتَتْهُ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ تَصَدَّقْتُ عَلَى أُمِّي بِجَارِيَةٍ وَإِنَّهَا مَاتَتْ ‏.‏ قَالَ ‏"‏ وَجَبَ أَجْرُكِ وَرَدَّهَا عَلَيْكِ الْمِيرَاثُ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا كَانَ عَلَيْهَا صَوْمُ شَهْرٍ أَفَأَصُومُ عَنْهَا قَالَ ‏"‏ صُومِي عَنْهَا ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا لَمْ تَحُجَّ قَطُّ أَفَأَحُجُّ عَنْهَا قَالَ ‏"‏ نَعَمْ حُجِّي عَنْهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَلاَ يُعْرَفُ هَذَا مِنْ حَدِيثِ بُرَيْدَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عَطَاءٍ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنَّ الرَّجُلَ إِذَا تَصَدَّقَ بِصَدَقَةٍ ثُمَّ وَرِثَهَا حَلَّتْ لَهُ ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّمَا الصَّدَقَةُ شَيْءٌ جَعَلَهَا لِلَّهِ فَإِذَا وَرِثَهَا فَيَجِبُ أَنْ يَصْرِفَهَا فِي مِثْلِهِ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ وَزُهَيْرُ بْنُ مُعَاوِيَةَ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ ‏.‏\hadithno{667}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Buraidah narrated from his father:"I was sitting with the Prophet when a woman came to him and said: 'O Messenger of Allah! I gave a slave girl to my mother in charity and she died.' He said: 'Your reward is already established, and your right to inherit her has returned it (that Sadaqah) to you.' She said: 'O Messenger of Allah! There was a month of fasting due on her, shall I perform the fast for her?' He said: 'Fast on her behalf.' She said: 'O Messenger of Allah! She never performed Hajj, shall I perform Hajj for her?' He said: 'Yes, perform Hajj on her behalf}}
\hadithdefcmd{tirmidhi}{668}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ حَمَلَ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ ثُمَّ رَآهَا تُبَاعُ فَأَرَادَ أَنْ يَشْتَرِيَهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ ‏.‏\hadithno{668}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that :Umar gave a horse to be used in the cause of Allah. Then he saw it being sold, so he wanted to buy it, but the Prophet said: "Do not take back what you have given in charity}}
\hadithdefcmd{tirmidhi}{669}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي تُوُفِّيَتْ أَفَيَنْفَعُهَا إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ لِي مَخْرَفًا فَأُشْهِدُكَ أَنِّي قَدْ تَصَدَّقْتُ بِهِ عَنْهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَبِهِ يَقُولُ أَهْلُ الْعِلْمِ ‏.‏ يَقُولُونَ لَيْسَ شَيْءٌ يَصِلُ إِلَى الْمَيِّتِ إِلاَّ الصَّدَقَةُ وَالدُّعَاءُ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ دِينَارٍ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ قَالَ وَمَعْنَى قَوْلِهِ إِنَّ لِي مَخْرَفًا ‏.‏ يَعْنِي بُسْتَانًا ‏.‏\hadithno{669}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ikrimah narrated from Ibn Abbas that :a man said: "O Messenger of Allah! My mother died, will it benefit her if I give charity on her behalf?" He said: 'Yes.' He said: 'I have a Makhraf, so bear witness that I have given it in charity on her behalf}}
\hadithdefcmd{tirmidhi}{670}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا شُرَحْبِيلُ بْنُ مُسْلِمٍ الْخَوْلاَنِيُّ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي خُطْبَتِهِ عَامَ حَجَّةِ الْوَدَاعِ يَقُولُ ‏"‏ لاَ تُنْفِقُ امْرَأَةٌ شَيْئًا مِنْ بَيْتِ زَوْجِهَا إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَلاَ الطَّعَامُ قَالَ ‏"‏ ذَاكَ أَفْضَلُ أَمْوَالِنَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي أُمَامَةَ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{670}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah Al-Bahili said:"During a sermon of his in the year of the Farewell Hajj, I heard the Messenger of Allah say: 'A woman is not to spend anything from her husbands house without her husband's permission.' They said: 'O Messenger of Allah! What about food?' He said: 'That is our most virtuous wealth}}
\hadithdefcmd{tirmidhi}{671}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا تَصَدَّقَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا كَانَ لَهَا بِهِ أَجْرٌ وَلِلزَّوْجِ مِثْلُ ذَلِكَ وَلِلْخَازِنِ مِثْلُ ذَلِكَ وَلاَ يَنْقُصُ كُلُّ وَاحِدٍ مِنْهُمْ مِنْ أَجْرِ صَاحِبِهِ شَيْئًا لَهُ بِمَا كَسَبَ وَلَهَا بِمَا أَنْفَقَتْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{671}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated that :the Prophet said: "When a woman gives in charity from her husband's house, she will get the reward for it, and for her husband is the same as that, and for the trustee is the same as that. The reward of each them will not be decreased at all by the reward of the other, for him is what he earned, and for her is what she spent}}
\hadithdefcmd{tirmidhi}{672}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْمُؤَمَّلُ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَعْطَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا بِطِيبِ نَفْسٍ غَيْرَ مُفْسِدَةٍ كَانَ لَهَا مِثْلُ أَجْرِهِ لَهَا مَا نَوَتْ حَسَنًا وَلِلْخَازِنِ مِثْلُ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَمْرِو بْنِ مُرَّةَ عَنْ أَبِي وَائِلٍ وَعَمْرُو بْنُ مُرَّةَ لاَ يَذْكُرُ فِي حَدِيثِهِ عَنْ مَسْرُوقٍ ‏.‏\hadithno{672}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that:the Messenger of Allah said: "When a woman gives from her husband's home, with a good heart, not to spoil it, then she will get a reward similar to his, for her is the good she intended - and the same is for the trustee}}
\hadithdefcmd{tirmidhi}{673}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم - صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ زَبِيبٍ أَوْ صَاعًا مِنْ أَقِطٍ فَلَمْ نَزَلْ نُخْرِجُهُ حَتَّى قَدِمَ مُعَاوِيَةُ الْمَدِينَةَ فَتَكَلَّمَ فَكَانَ فِيمَا كَلَّمَ بِهِ النَّاسَ إِنِّي لأَرَى مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ تَعْدِلُ صَاعًا مِنْ تَمْرٍ ‏.‏ قَالَ فَأَخَذَ النَّاسُ بِذَلِكَ ‏.‏ قَالَ أَبُو سَعِيدٍ فَلاَ أَزَالُ أُخْرِجُهُ كَمَا كُنْتُ أُخْرِجُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَرَوْنَ مِنْ كُلِّ شَيْءٍ صَاعًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ مِنْ كُلِّ شَيْءٍ صَاعٌ إِلاَّ مِنَ الْبُرِّ فَإِنَّهُ يُجْزِئُ نِصْفُ صَاعٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَأَهْلِ الْكُوفَةِ يَرَوْنَ نِصْفَ صَاعٍ مِنْ بُرٍّ ‏.‏\hadithno{673}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"We would give Zakat Al-Fitr - when the Messenger of Allah was among us - as a Sa of food, or a Sa of barely, or a Sa of dried dates, or a Sa of raisins, or a Sa of cheese. So we did not stop paying it (like that) until Mu'awiyah arrived in Al-Madinah and talked (about it). Among the things he addressed the people with, he said: 'I see that two Mudd of the wheat of Ash-Sham are equal to a Sa of dried dates.' So the people followed that." Abu Sa'eed said: "I will not stop giving it in the manner that I had been giving it}}
\hadithdefcmd{tirmidhi}{674}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْبَصْرِيُّ، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ مُنَادِيًا فِي فِجَاجِ مَكَّةَ ‏ "‏ أَلاَ إِنَّ صَدَقَةَ الْفِطْرِ وَاجِبَةٌ عَلَى كُلِّ مُسْلِمٍ ذَكَرٍ أَوْ أُنْثَى حُرٍّ أَوْ عَبْدٍ صَغِيرٍ أَوْ كَبِيرٍ مُدَّانِ مِنْ قَمْحٍ أَوْ سِوَاهُ صَاعٌ مِنْ طَعَامٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى عُمَرُ بْنُ هَارُونَ هَذَا الْحَدِيثَ عَنِ ابْنِ جُرَيْجٍ وَقَالَ عَنِ الْعَبَّاسِ بْنِ مِينَاءَ عَنِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ بَعْضَ هَذَا الْحَدِيثِ ‏.‏ حدثنا جارود حدثنا عمر بن هارون هذا الحديث\hadithno{674}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his grandfather that :the Prophet sent a caller in the roads of Makkah proclaiming "Sadaqatul-Fitr is required upon every Muslim, male or female, free or slave, young or old; it is two Mudd of wheat or its equivalent of a Sa of food}}
\hadithdefcmd{tirmidhi}{675}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَدَقَةَ الْفِطْرِ عَلَى الذَّكَرِ وَالأُنْثَى وَالْحُرِّ وَالْمَمْلُوكِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏ قَالَ فَعَدَلَ النَّاسُ إِلَى نِصْفِ صَاعٍ مِنْ بُرٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ وَجَدِّ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ وَثَعْلَبَةَ بْنِ أَبِي صُعَيْرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{675}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"The Messenger of Allah made Sadaqatul-Fitr an obligation upon the male and female, the free and the bondsmen, as a Sa of dried dates or a Sa of barley." He said: "So the people equated that to half a Sa of wheat}}
\hadithdefcmd{tirmidhi}{676}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ مِنْ رَمَضَانَ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى مِنَ الْمُسْلِمِينَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى مَالِكٌ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ أَيُّوبَ وَزَادَ فِيهِ مِنَ الْمُسْلِمِينَ ‏.‏ وَرَوَاهُ غَيْرُ وَاحِدٍ عَنْ نَافِعٍ وَلَمْ يَذْكُرْ فِيهِ مِنَ الْمُسْلِمِينَ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَقَالَ بَعْضُهُمْ إِذَا كَانَ لِلرَّجُلِ عَبِيدٌ غَيْرُ مُسْلِمِينَ لَمْ يُؤَدِّ عَنْهُمْ صَدَقَةَ الْفِطْرِ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ وَأَحْمَدَ ‏.‏ وَقَالَ بَعْضُهُمْ يُؤَدِّي عَنْهُمْ وَإِنْ كَانُوا غَيْرَ مُسْلِمِينَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَإِسْحَاقَ ‏.‏\hadithno{676}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"The Messenger of Allah made Sadaqatul-Fitr of Ramadan an obligation - a Sa of dried dates or a Sa of barley - required upon every free person and slave, male and female among the Muslims}}
\hadithdefcmd{tirmidhi}{677}{حَدَّثَنَا مُسْلِمُ بْنُ عَمْرِو بْنِ مُسْلِمٍ أَبُو عَمْرٍو الْحَذَّاءُ الْمَدَنِيُّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، عَنِ ابْنِ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِإِخْرَاجِ الزَّكَاةِ قَبْلَ الْغُدُوِّ لِلصَّلاَةِ يَوْمَ الْفِطْرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَهُوَ الَّذِي يَسْتَحِبُّهُ أَهْلُ الْعِلْمِ أَنْ يُخْرِجَ الرَّجُلُ صَدَقَةَ الْفِطْرِ قَبْلَ الْغُدُوِّ إِلَى الصَّلاَةِ ‏.‏\hadithno{677}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that :the Messenger of Allah would order paying the Zakat before going to the Salat on the day of Fitr}}
\hadithdefcmd{tirmidhi}{678}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّا، عَنِ الْحَجَّاجِ بْنِ دِينَارٍ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ حُجَيَّةَ بْنِ عَدِيٍّ، عَنْ عَلِيٍّ، أَنَّ الْعَبَّاسَ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ تَعْجِيلِ صَدَقَتِهِ قَبْلَ أَنْ تَحِلَّ فَرَخَّصَ لَهُ فِي ذَلِكَ ‏.‏\hadithno{678}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated:"Al-Abbas asked the Messenger of Allah about paying his charity (Zakat) in advance before its time is due (by being in possession for a whole year), he permitted him to do that}}
\hadithdefcmd{tirmidhi}{679}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ إِسْرَائِيلَ، عَنِ الْحَجَّاجِ بْنِ دِينَارٍ، عَنِ الْحَكَمِ بْنِ جَحْلٍ، عَنْ حُجْرٍ الْعَدَوِيِّ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعُمَرَ ‏ "‏ إِنَّا قَدْ أَخَذْنَا زَكَاةَ الْعَبَّاسِ عَامَ الأَوَّلِ لِلْعَامِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى لاَ أَعْرِفُ حَدِيثَ تَعْجِيلِ الزَّكَاةِ مِنْ حَدِيثِ إِسْرَائِيلَ عَنِ الْحَجَّاجِ بْنِ دِينَارٍ إِلاَّ مِنْ هَذَا الْوَجْهِ وَحَدِيثُ إِسْمَاعِيلَ بْنِ زَكَرِيَّا عَنِ الْحَجَّاجِ عِنْدِي أَصَحُّ مِنْ حَدِيثِ إِسْرَائِيلَ عَنِ الْحَجَّاجِ بْنِ دِينَارٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي تَعْجِيلِ الزَّكَاةِ قَبْلَ مَحِلِّهَا فَرَأَى طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ أَنْ لاَ يُعَجِّلَهَا ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ قَالَ أَحَبُّ إِلَىَّ أَنْ لاَ يُعَجِّلَهَا ‏.‏ وَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ إِنْ عَجَّلَهَا قَبْلَ مَحِلِّهَا أَجْزَأَتْ عَنْهُ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{679}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that :the Prophet said to Umar: "We have taken this year's Zakat from Al-Abbas in the previous year}}
\hadithdefcmd{tirmidhi}{680}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ بَيَانِ بْنِ بِشْرٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لأَنْ يَغْدُوَ أَحَدُكُمْ فَيَحْتَطِبَ عَلَى ظَهْرِهِ فَيَتَصَدَّقَ مِنْهُ فَيَسْتَغْنِيَ بِهِ عَنِ النَّاسِ خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ رَجُلاً أَعْطَاهُ أَوْ مَنَعَهُ ذَلِكَ فَإِنَّ الْيَدَ الْعُلْيَا أَفْضَلُ مِنَ الْيَدِ السُّفْلَى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حَكِيمِ بْنِ حِزَامٍ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَالزُّبَيْرِ بْنِ الْعَوَّامِ وَعَطِيَّةَ السَّعْدِيِّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَمَسْعُودِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ وَثَوْبَانَ وَزِيَادِ بْنِ الْحَارِثِ الصُّدَائِيِّ وَأَنَسٍ وَحُبْشِيِّ بْنِ جُنَادَةَ وَقَبِيصَةَ بْنِ مُخَارِقٍ وَسَمُرَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ يُسْتَغْرَبُ مِنْ حَدِيثِ بَيَانٍ عَنْ قَيْسٍ ‏.‏\hadithno{680}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that he heard :the Messenger of Allah saying: "For one of you to go out early to gather firewood and carry it on his back so that he can give charity from it and be free of need from the people, is better for him than to ask a man who may give that to him or refuse. Indeed the upper hand (giving) is more virtuous than the lower hand (receiving), and begin with (those who are) your dependants}}
\hadithdefcmd{tirmidhi}{681}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيِعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ زَيْدِ بْنِ عُقْبَةَ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَسْأَلَةَ كَدٌّ يَكُدُّ بِهَا الرَّجُلُ وَجْهَهُ إِلاَّ أَنْ يَسْأَلَ الرَّجُلُ سُلْطَانًا أَوْ فِي أَمْرٍ لاَ بُدَّ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{681}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Samurah bin Jundub narrated that :the Messenger of Allah said: "Asking is a labor that toils on a man's face, except if a man asks for something from the Sultan (ruler), or he asks for something that he cannot do without}}
